%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% fmcross                          fmcross.m                     fmcross
% =========================================================================  
% Genetic Algorithms Tools for MathTools 
% =========================================================================  
%                             Copyright (c) 1999, 2000
%                       Flexible Intelligence Group (FIG)       	             
%                   P. O. Box 861477, Tuscaloosa, AL 35486, USA.            
% ========================================================================= 
%  PURPOSE 
%          Crossover Function. 
%          Do the 1 or multi-point crossover operation for GA 
% ......................................................................... 
%  OPERATION 
%         Based on crossover rate, randomly selects crossover points, 
%	  preforms crossover,  repeats Ncross times. 
% ........................................................................... 
%  RETURNS 
%         x1n(1:Lchrom), and x2n(1:Lchrom), the newly formed chromosomes 
% ........................................................................... 
%  APPLICATION 
%         In GA applications, for providing random information exchange. 
%		  (recombination of building blocks) 
% ........................................................................... 
%  USES
%       rand, fix, if, for 
%  ========================================================================== 
%  SYNTAX / USAGE 
%       [x1n(1:Lchrom),x2n(1:Lchrom)] = fmcross(gap,fud,x1o(1:Lchrom),x2o(1:Lchrom))  
%       [x1n,x2n] = fmcross(gap,fud,x1o,x2o) 
%  
%=========================================================================

%  FUNCTION DECLARATION 
function [x1n,x2n]=fmcross(gap,fud,x1o,x2o) 
 
%=========================================================================
%  CODE  
 
%  SHARED DATA

Npop	=gap(3);
Lchrom	=fud(97);
Noofp	=fud(98);
Noofobj	= fud(99); 
mm	= fud(100:(100+Noofobj-1));
Ncross	=gap(9);
pcross	=gap(8);

for i=1:Ncross 
                x1s=x1o; x2s=x2o; 
                if(rand(1) < pcross) 
                        site=fix(rand(1)*Lchrom); 
                        if(site > 1) 
                          x1s(site:Lchrom)=x2s(site:Lchrom); 
                          x2o(site:Lchrom)=x1o(site:Lchrom);  
                        end % if 
                end % if 

[nm101, nn101]=size(x1s);
for i=1:nm101 
pssparam(1)=1;
[pssparam(2), pssparam(3)]=size(x1s);
[pssparam(4), pssparam(5)]=size(x2o);
[x1n(i,:), x2n(i,:)]=ftgalib(pssparam, x1s(i,:), x2o(i,:));
pssparam(1)=1;
[pssparam(2), pssparam(3)]=size(x1n);
[pssparam(4), pssparam(5)]=size(x2n);
[x1o(i,:), x2o(i,:)]=ftgalib(pssparam, x1n(i,:), x2n(i,:));
end % if


end % for loop 
%=========================================================================
% (c) Flexible Intelligence Group (FIG) 
% END fmcross.m   
% fmcross                          fmcross.m                     fmcross
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
