%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 
% fmdecode                        fmdecode.m                     fmdecode  
% =========================================================================  
% Genetic Algorithms Tools for MathTools 
% =========================================================================  
%                             Copyright (c) 1999, 2000
%                       Flexible Intelligence Group (FIG)       	             
%                   P. O. Box 861477, Tuscaloosa, AL 35486, USA.            
% =========================================================================  
% =========================================================================  
%  PURPOSE  
%          Decode a given chromosome into the actual parameters  
% .........................................................................  
%  GIVEN                              
%	pop	:  chromosome x(1:Lchrom)  
%	gap
%	fud
%	fpd
%	mean_table
%	sigma_table
%	pot_table
%	fname
% ...........................................................................  
%  OPERATION  
%         Decodes the string based on the max, min, resolution and coding  
% ...........................................................................  
%  RETURNS  
% 	P	:  Decoded Parameters P(1:Noofp)  
%	PI	:  Performance Index PI(1:Noofobj)
%	mean_table
%	sigma_table
% ...........................................................................  
%  APPLICATION  
%         In GA applications, part of intitialization.  
% ...........................................................................  
%  USES
%       if, for 
%  ==========================================================================  
%  SYNTAX / USAGE  
%    [P,PI,mean_table,sigma_table]=fmdecode(pop,gap,fud,fpd,mean_table,sigma_table,pot_table,fname)  
%  ========================================================================== 

%  FUNCTION DECLARATION  
function [P,PI,mean_table,sigma_table]=fmdecode(pop,gap,fud,fpd,mean_table,sigma_table,pot_table,fname)  
 
%  ==========================================================================  
%  CODE    
  
%  SHARED DATA

P_type		= fpd(1,:);
Nbits		= fpd(5,:);
pslope		= fpd(7,:);
pc       	= fpd(6,:);



tempin(1)=fud(97);
tempin(2)=max(size(P_type));
tempin(3)=gap(13);	
pssparam(1)=2;
[pssparam(2), pssparam(3)]=size(tempin);
[temp]=ftgalib(pssparam, tempin);
Lchrom		= temp(1);
Noofp		= temp(2);
mchild		= temp(3);


% LOCAL VARIABLES

	ebit=0;  
	grand=randn(Noofp*mchild,1);
	count=0;

	for i=1:Noofp  
		sbit=ebit+1;
		ebit=sbit+Nbits(i)-1;  

		if P_type(i) <= 2
        	decval(i)=sum(pot_table(1:Nbits(i)).*pop(sbit:ebit))+1;
			P(i)= (decval(i)-1)*pslope(i)+pc(i);  
			if P_type(i)==1, P(i)=fix(P(i)); end
			P_P(:,i)=P(i)*ones(mchild,1);
		end

		if P_type(i) > 2
			decval(i)=sum(pot_table(1:Nbits(i)).*pop(sbit:ebit))+1;
			xmean=mean_table(decval(i),i);
			xsigma=sigma_table(decval(i),i);

			for ii=1:(mchild-1)
				count=count+1; 
				P_P(ii,i)=xmean+grand(count,1)*xsigma;
			end
			P_P(mchild,i)=xmean;
      		end

	end % i for loop  
	dummy=find(P_type > 2);

	if isempty(dummy) == 1, mchild=1; end	%Make sure stochastic GA is necessary
	clear dummy


	for ii=1:mchild
      		PI_P(ii,:)=feval(fname,P_P(ii,:));
	end
   
   %POSSIBLE LOCATION FOR LICENSE
   [yjunk,ijunk]=sort(PI_P);
   
	for i=1:Noofp
		mean_table(decval(i),i)=P_P(ijunk(1),i);
	end
	PI=PI_P(ijunk(1),:);
	P=P_P(ijunk(1),:);

%=========================================================================  
% (c) Flexible Intelligence Group (FIG)  
% END fmdecode.m  
% fmdecode                        fmdecode.m                     fmdecode  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

