%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% fmga_def                    fmga_def.m                           fmga_def 
% =========================================================================  
% Genetic Algorithms Tools for MathTools 
% =========================================================================  
%                             Copyright (c) 1999, 2000
%                       Flexible Intelligence Group (FIG)       	             
%                   P. O. Box 861477, Tuscaloosa, AL 35486, USA.            
% =========================================================================   
%  PURPOSE   
%          Generate default values for flexga software 
% .........................................................................   
%  GIVEN   
%         gap_choice
%		=1 	Small problem; 	10 parameters or less; 	Regular GA
%		=2   	Medium problem; 	30 parameters or less; 	Regular GA
%		=3 	Small problem; 	10 parameters or less;	Micro GA
%		=4   	Medium problem; 	30 parameters or less;	Micro GA
%		=5 	Small problem;		10 parameters or less;	Steady-state GA
%		=6   	Medium problem;	30 parameters or less;	Steady-state GA 	
%		=7		Big problem;		30 parameters or more	Steady-state GA
% ...........................................................................   
%  RETURNS   
%         gap:  GA_parameter list that can be used with flexga
% ...........................................................................   
%  APPLICATION   
%         In flexga applications
% ...........................................................................   
%  USES
%  ==========================================================================   
%  SYNTAX / USAGE  
%       gap=fmga_def(gap_choice) 
%  ==========================================================================   

%  FUNCTION DECLARATION   
function gap=fmga_def(gap_choice)   
   
%=========================================================================   
%  CODE    
if nargin < 1
	eval('help fmga_def');
else
	if gap_choice==1 	%small problem; 10 parameters or less; with Regular GA
		gap=[1 30 31 1 2 2 1 0.77 2 0.0077];
	end
	if gap_choice==2   	% Medium problem; 30 parameters or less; with Regular GA
		gap=[1 30 61 1 2 2 1 0.77 2 0.0077];
	end
	if gap_choice==3 	%small problem; 10 parameters or less; with Micro GA
		gap=[2 30 5 1 2 2 1 0.77 2 0.0 0.0 5];
	end
	if gap_choice==4   	% Medium problem; 30 parameters or less; with Micro GA
		gap=[2 30 5 1 2 2 1 0.77 3 0.0 0.0 5];
	end
	if gap_choice==5 	%small problem; 10 parameters or less; with Steady-state GA
		gap=[3 30 31 1 2 2 15 0.77 2 0.0077];
	end
	if gap_choice==6   	% Medium problem; 30 parameters or less; with Steady-state GA 
		gap=[3 60 61 1 2 2 31 0.77 3 0.0077];
	end
	if gap_choice==7	% Big problem; 30 parameters or more with Steady-state GA
		gap=[3 100 101 1 2 2 51 0.77 4 0.0077];
	end
end
%=========================================================================   
% (c) Flexible Intelligence Group (FIG)   
% END fmga_def.m   
% fmga_def                        fmga_def.m                        fmga_def 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

