%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% fmgen                           fmgen.m                           fmgen 
% =========================================================================  
% Genetic Algorithms Tools for MathTools 
% =========================================================================  
%                             Copyright (c) 1999, 2000
%                       Flexible Intelligence Group (FIG)       	             
%                   P. O. Box 861477, Tuscaloosa, AL 35486, USA.            
% =========================================================================   
%  PURPOSE   
%          Generation Function. An iteration of the creation of a new   
%          population using reproduction operators. Use a measure of fitness   
%          (PI).   
% .........................................................................   
%  GIVEN   
%         gap
%         fud
%         oldpop	:  Old Population of chromosomes oldpop(1:Npop,1:lchrom)   
%         PI	:  Performance Index PI(1:Npop)    
% ...........................................................................   
%  OPERATION   
%         performs, selection, crossover, mutation, reproduce new generation   
%         of population   
% ...........................................................................   
%  RETURNS   
%         newpop:  New Population of chromosomes newpop(1:Npop,1:lchrom)   
% ...........................................................................   
%  APPLICATION   
%         In GA applications, for reproducing the next generation of    
%         population.   
% ...........................................................................   
%  USES
%       fmselect.m, fmcross.m, fmmutate.m
%  ==========================================================================   
%  SYNTAX / USAGE  
%       [newpop]=fmgen(gap,fud,oldpop(1:Npop,1:lchrom),PI(1:Npop))    
%       [newpop]=fmgen(gap,fud,oldpop,PI)   
%  
%  ==========================================================================   

%  FUNCTION DECLARATION   
function [newpop]=fmgen(gap,fud,oldpop,PI)   
   
%==========================================================================   
%  CODE    
   
% SHARED DATA   

Npop	= gap(3);
Nsspop	= gap(7);
Nselect	= gap(5);  
Noofobj	= fud(99); 
mm	= fud(100:(100+Noofobj-1));
   
    %---------------------------------   
    % CALL fmselect.m (Selection) 
    %--------------------------------- 
    [xpop]=fmselect(gap,fud,oldpop,PI);   
    newpop=xpop;
    for i=1:2:(Npop-Nsspop)   
        %-----------------------------------   
        % CALL fmcross.m  (Crossover) 
        %-----------------------------------   
        x1o=xpop(i,:);   
        x2o=xpop((i+1),:);           
        [x1n,x2n]=fmcross(gap,fud,x1o,x2o); 
        %----------------------------------   
        % CALL fmmutate.m (Mutation)   
        %----------------------------------   
        x1n=fmmutate(gap,fud,x1n);
        x2n=fmmutate(gap,fud,x2n);   
        %---------------------------   
        % NEW POPULATION   
        %---------------------------   


pssparam(1)=1;
[pssparam(2), pssparam(3)]=size(x1n);
[pssparam(4), pssparam(5)]=size(x2n);
[newpop(i,:), newpop((i+1),:)]=ftgalib(pssparam, x1n, x2n);




    end % i for loop   
%==========================================================================   
% (c) Flexible Intelligence Group (FIG)   
% END fmgen.m   
% fmgen                            fmgen.m                          fmgen 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
