%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% fmnich                           fmnich.m                        fmnich
% =========================================================================  
% Genetic Algorithms Tools for MathTools 
% =========================================================================  
%                             Copyright (c) 1999, 2000
%                       Flexible Intelligence Group (FIG)       	             
%                   P. O. Box 861477, Tuscaloosa, AL 35486, USA.            
%  ==========================================================================   
%  PURPOSE   
%          Sharing fitness function.   
%          To Induce Niche-like behavior in genetic search   
%  .........................................................................   
%  GIVEN
%         fud	 : Function Descriptors   
%         Npop	 :  Number of population    
%         Noofp	 :  Number of parameters    
%         fitness:  Fitness of the members(Npop) of the population vector   
%                   for a particular generation  fitness(Npop)   
%         p	 :  The parameters matrix  p(Noofp,Npop)   
%         pmax	 :  Maximum value of parameters vector  pmax(Noofp)   
%         pmin	 :  Minimum value of parameters vector  pmin(Noofp)   
%         q_peaks:  Number of assumed peaks    
%  ...........................................................................   
%  OPERATION   
%         Computes new fitness for the members of the population   
%         based on the sharing function   
%  ...........................................................................   
%  RETURNS   
%         The modified fitness   
%  ...........................................................................   
%  APPLICATION   
%         Discovering multiple solutions, multiple fuzzy models, etc.   
%  ...........................................................................   
%  USES
%       zeros, for, norm
%  ==========================================================================   
%   SYNTAX  /  USAGE  
%   fitness=fmnich(fud,Npop,Noofp,fitness(1:Npop),p(1:Noofp,1:Npop),pmax(1:Npop),..
%               pmin(1:Npop),q_peaks)   
%   fitness=fmnich(fud,Npop, Noofp, fitness, p, pmax, pmin, q_peaks)   
%  ==========================================================================  

%  FUNCTION DECLARATION   
   function fitness = fmnich(fud,Npop,Noofp,fitness,p,pmax,pmin,q_peaks)   
%  ==========================================================================   
%  SHARED DATA   
    Noofobj=fud(99);
    mm=fud(100:(100+Noofobj-1));
    Noofp=max(size(pmin));
    
% Reassign signs of the fitnesses
    fitness=fitness*mm;

% Change minimization to maximization
    if  mm ==  1
    	maxfit=max(fitness);
   	fitness=maxfit*ones(Npop,1)-fitness;   
    end % if   
   
%  Compute the limiting distance between the individuals to be shared   
     sig_share = 0.5 * q_peaks^(-1/Noofp);   
   
%  ------------------------------------------------------   
%  Initialize the distance and sharing_func matrix    
%  ------------------------------------------------------   
    distance     = zeros(Npop,Npop);   
    sharing_func = zeros(Npop);   
   
%  ------------------------------------   
%  Compute the distance measure    
%  ------------------------------------   

	for i=1:Npop
     for j=1:Noofp
        scaled_P(j,i) = p(j,i) / ((pmax(j)-pmin(j)));   
     end
   end % i for loop   

   for i=1:Npop    
	for j=i:Npop    
		vec = scaled_P(:,i) - scaled_P(:,j);   
		distance(i,j) = norm(vec);   
		distance(j,i) = distance(i,j);   
	end % j for loop   
   end % i for loop   

%   ---------------------------------------------------------------------   
%   Sum the sharing_func,   
%   Compute the shared fitness = true fitness (* | /) sum of sharing_func    
%   ---------------------------------------------------------------------   
    for i=1:Npop    
	for j=1:Npop    
	   %  sum the sharing_func   
	   if(distance(i,j) < sig_share)   
	   	sharing_func(i) = sharing_func(i) + (1-distance(i,j)/sig_share);   
	   end % if   
	end %  j for loop   

	%  Compute Shared Fitness    
	%  based on maximization or minimization scheme   
	maxfit=max(fitness);
	if(sharing_func(i) > 0.0)   
	 	fitness(i) = fitness(i) / sharing_func(i);     
	end %  if   
    end %  i for loop   

% Reset signs of the fitnesses and the sense of optimization
    fitness=fitness*mm;

    if  mm ==  1
	maxfit=max(fitness);
   	fitness=maxfit*ones(Npop,1)-fitness;   
    end % if   
%  ========================================================================   
% (c) Flexible Intelligence Group (FIG)   
% END fmnich.m     
% fmnich                           fmnich.m                        fmnich
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
