%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% fmselect                       fmselect.m                     fmselect
% =========================================================================  
% Genetic Algorithms Tools for MathTools 
% =========================================================================  
%                             Copyright (c) 1999, 2000
%                       Flexible Intelligence Group (FIG)       	             
%                   P. O. Box 861477, Tuscaloosa, AL 35486, USA.            
% =========================================================================   
%  PURPOSE   
%          Selection Function. Individuals from the old population are   
%          copied to a mating pool. Fit individuals will have more   
%          copies in the pool. Models nature's survival of the fittest   
%          mechanism.   
% .........................................................................   
%  GIVEN   
%         oldpop:  Old Population of chromosomes oldpop(1:Npop,1:Lchrom)   
%         PI	:  Performance Index PI(1:Npop)    
%         Npop	:  Number of population   
%         Nsspop	:  This Population will not be replaced   
%         nselec:  Selection scheme choice   
%                        1. Tournament Selection   
%                        2. Roulette-Wheel Selection   
%                        3. Ranking Selection   
%         nrank	:     
%         mm	:  Maximization (mm<>1) or Minimization (mm==1)   
%         Noofob:  Number of objectives (1-4 allowed here)   
%         Tsize	:  Tournament Size (for tournament selection)   
% ...........................................................................   
%  OPERATION   
%         performs, selection of population based on the value of Nselect.   
% ...........................................................................   
%  RETURNS   
%         newpop:  New Population of chromosomes newpop(1:Npop,1:Lchrom)   
% ...........................................................................   
%  APPLICATION   
%         In GA applications, for selecting suitable parents to mate and   
%         reproduce to form the next generation (of population).   
% ...........................................................................   
%   USES
%       fmshuffl.m
%       if, while, for, min, round, sort, sum, size, zeros, mean 
%  ==========================================================================   
%  SYNTAX  /  USAGE  
%       newpop=fmselect(gap,fud,oldpop(1:Npop,1:Lchrom),PI(1:Npop))    
%       newpop=fmselect(gap,fud,oldpop,PI)   
% ==========================================================================   

%  FUNCTION DECLARATION   
function [newpop]=fmselect(gap,fud,oldpop,PI)   
   
%  ==========================================================================   
%  CODE    
   
% SHARED DATA   

pssparam(1)=2;
[pssparam(2), pssparam(3)]=size(gap);
[temp]=ftgalib(pssparam, gap);
Npop	=temp(3);
Tsize	=temp(6);
Nsspop	=temp(7);
Nselect	=temp(5);

%-----
Noofobj	= fud(99);
mm	= fud(100:(100+Noofobj-1));

PIN=PI(:,1);   

j=0; i=0;   
%-------------------
% CALL fmshuffl.m
%-------------------
index=fmshuffl(Npop);   
newpop=oldpop;       
%----------------------------   
% Tournament Selection   
%----------------------------       
if Nselect == 2   
	if Noofobj ==1, J1=Npop; J2=Npop; J3=Npop; J4=Npop; end   
%	if Noofobj ==2, J1=fix(Npop/2); J2=Npop; J3=Npop; J4=Npop; end   
%	if Noofobj ==3, J1=fix(Npop/3); J2=2*J1; J3=Npop; J4=Npop; end   
%	if Noofobj ==4, J1=fix(Npop/4); J2=2*J1; J3=3*J1; J4=Npop; end   
	while j < Npop-Nsspop   
    	j=j+1;   
    
    	for k=1:Tsize   
      		pin(k)=PIN(index(k+i));   
      		INDEX(k)=index(k+i);   
    	end % k for loop   
		[Y,I]=min(pin);
	
		newpop(j,:)=oldpop(INDEX(I),:);   
    	i=i+Tsize;   
	%-------------------
	% CALL fmshuffl.m
	%-------------------
    	if i > (Npop-Tsize), i=1; index=fmshuffl(Npop); end   
%		if j > J1, PIN=PI(:,2); end   
%    	if j > J2, PIN=PI(:,3); end   
%    	if j > J3, PIN=PI(:,4); end   
end  % while loop  

%------------------------   
% Ranking Selection   
%------------------------   
elseif Nselect == 3   
    PIN=PI(:,1);         
    nrank=round(Npop/2);   
    [PIN,ind]=sort(PIN);   % Sort PI on the Basis of Fitness   
    dum=sum(PIN(1:nrank));   
    k=1;   
    while k <= Npop   
    	for i=1:nrank 	 % Assign "newpop" on the Basis of Rank   
     		tmp=round(PIN(i)*Npop/dum);   
     		for j=1:tmp   
       			newpop(k,:)=oldpop(ind(i),:);   
       			k=k+1;   
     		end   
   		end   
  	end   
%--------------------------------   
% Roulette Wheel Selection   
%--------------------------------  	   
else   
  	copy=zeros(Npop,1);   
  	PIN=max(PI)-PI(:,1);
  	tf=mean(PIN);   
   
  	for i=1:Npop   
    	   copy(i)=round(PIN(i)/tf);   
  	end   
   
  	k=0;   
  	i=0;   
  	while k <= Npop   
    	i=i+1;   
    	if i > Npop, i=1; end   
    	for j=1:copy(i)   
      		k=k+1;   
      		newpop(k,:)=oldpop(i,:);   
    	end % end j loop   
  	end % end k loop   
   
end % end if loop   
%  ==========================================================================   
% (c) Flexible Intelligence Group (FIG)   
% END fmselect.m   
% fmselect                       fmselect.m                     fmselect
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
