%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% fmstats                        fmstats.m                       fmstats
% =========================================================================  
% Genetic Algorithms Tools for MathTools 
% =========================================================================  
%                             Copyright (c) 1999, 2000
%                       Flexible Intelligence Group (FIG)       	             
%                   P. O. Box 861477, Tuscaloosa, AL 35486, USA.            
% =========================================================================   
%  PURPOSE   
%          Compute statistics: max, min, average, standard deviation from   
%          the performance index values   
% .........................................................................   
%  GIVEN   
%         PI	:  Performance Index PI(1:Npop)    
%      GLOBAL   
%         Npop	:  Number of population   
% ...........................................................................   
%  OPERATION   
%         computes maximum and minimum PI, average, standard deviation   
% ...........................................................................   
%  RETURNS   
%         maxi	:  max. val. of PI   
%         mini	:  min. val. of PI   
%         avg	:  average value of PI   
%         sd	:  standard deviation   
%         Nmax	:  index of maximum value   
%         Nmin	:  index of minimum value   
% ...........................................................................   
%  APPLICATION   
%         In GA applications, for computing statistics    
% ...........................................................................   
%   USES
%       max, min, avg, mean, std
%  ==========================================================================   
%  SYNTAX  /  USAGE  
%      [maxi,mini,avg,sd,Nmax,Nmin]=fmstats(PI(1:Npop))    
%      [maxi,mini,avg,sd,Nmax,Nmin]=fmstats(PI)   
%  ==========================================================================  
   
%  FUNCTION DECLARATION   
function [maxi,mini,avg,sd,Nmax,Nmin]=fmstats(PI)   
 
%  CODE    
   
% SHARED DATA
        x=PI;   
        [maxi,Nmax]=max(x);   
        [mini,Nmin]=min(x);   
        avg=mean(x);   
        sd=std(x);   
%=========================================================================   
% (c) Flexible Intelligence Group (FIG)   
% END fmstats.m   
% fmstats                        fmstats.m                       fmstats
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
